@@ -1,5 +1,5 @@
-use ansiterm::Colour::*;
-use ansiterm::Style;
+use nu_ansi_term::Color::*;
+use nu_ansi_term::Style;
 use std::default::Default;
 
 use crate::output::color_scale::{ColorScaleMode, ColorScaleOptions};
@@ -113,6 +113,7 @@ impl UiStyles {
             inode: Purple.normal(),
             blocks: Cyan.normal(),
             octal: Purple.normal(),
+            flags: Style::default(),
             header: Style::default().underline(),
 
             symlink_path: Cyan.normal(),
